@@ -43,10 +43,18 @@ USERENA_FORBIDDEN_USERNAMES = getattr(settings,
                                       ('signup', 'signout', 'signin',
                                        'activate', 'me', 'password'))
 
+USERENA_USE_HTTPS = getattr(settings,
+                            'USERENA_USE_HTTPS',
+                            False)
+
 USERENA_MUGSHOT_GRAVATAR = getattr(settings,
                                    'USERENA_MUGSHOT_GRAVATAR',
                                    True)
 
+USERENA_MUGSHOT_GRAVATAR_SECURE = getattr(settings,
+                                          'USERENA_MUGSHOT_GRAVATAR_SECURE',
+                                          USERENA_USE_HTTPS)
+
 USERENA_MUGSHOT_DEFAULT = getattr(settings,
                                   'USERENA_MUGSHOT_DEFAULT',
                                   'identicon')
@@ -55,14 +63,14 @@ USERENA_MUGSHOT_SIZE = getattr(settings,
                                'USERENA_MUGSHOT_SIZE',
                                80)
 
+USERENA_MUGSHOT_CROP_TYPE = getattr(settings,
+                                    'USERENA_MUGSHOT_CROP_TYPE',
+                                    'smart')
+
 USERENA_MUGSHOT_PATH = getattr(settings,
                                'USERENA_MUGSHOT_PATH',
                                'mugshots/')
 
-USERENA_USE_HTTPS = getattr(settings,
-                            'USERENA_USE_HTTPS',
-                            False)
-
 USERENA_DEFAULT_PRIVACY = getattr(settings,
                                   'USERENA_DEFAULT_PRIVACY',
                                   'registered')
@@ -82,3 +90,8 @@ USERENA_LANGUAGE_FIELD = getattr(settings,
 USERENA_WITHOUT_USERNAMES = getattr(settings,
                                     'USERENA_WITHOUT_USERNAMES',
                                     False)
+
+USERENA_PROFILE_DETAIL_TEMPLATE = getattr(
+    settings, 'USERENA_PROFILE_DETAIL_TEMPLATE', 'userena/profile_detail.html')
+
+USERENA_HIDE_EMAIL = getattr(settings, 'USERENA_HIDE_EMAIL', False)
