@@ -1,14 +1,16 @@
-from django.views.generic.simple import direct_to_template
 from django.core.urlresolvers import reverse
 from django.shortcuts import redirect, get_object_or_404
 from django.contrib.auth import authenticate, login, logout, REDIRECT_FIELD_NAME
 from django.contrib.auth.forms import PasswordChangeForm
 from django.contrib.auth.decorators import login_required
 from django.contrib.auth.models import User
+from django.contrib.auth.views import logout as Signout
+from django.views.generic import TemplateView
+from django.template.context import RequestContext
+from django.views.generic.list import ListView
 from django.conf import settings
 from django.contrib import messages
 from django.utils.translation import ugettext as _
-from django.views.generic import list_detail
 from django.http import HttpResponseForbidden, Http404
 
 from userena.forms import (SignupForm, SignupFormOnlyEmail, AuthenticationForm,
@@ -22,6 +24,51 @@ from userena import settings as userena_settings
 
 from guardian.decorators import permission_required_or_403
 
+import warnings
+
+class ExtraContextTemplateView(TemplateView):
+    """ Add extra context to a simple template view """
+    extra_context = None
+
+    def get_context_data(self, *args, **kwargs):
+        context = super(ExtraContextTemplateView, self).get_context_data(*args, **kwargs)
+        if self.extra_context:
+            context.update(self.extra_context)
+        return context
+        
+class ProfileListView(ListView):
+    """ Lists all profiles """
+    context_object_name='profile_list'
+    page=1
+    paginate_by=50
+    template_name='userena/profile_list.html'
+    extra_context=None
+    
+    def get_context_data(self, **kwargs):
+        # Call the base implementation first to get a context
+        context = super(ProfileListView, self).get_context_data(**kwargs)
+        try:
+            page = int(self.request.GET.get('page', None))
+        except (TypeError, ValueError):
+            page = self.page
+    
+        if userena_settings.USERENA_DISABLE_PROFILE_LIST \
+           and not self.request.user.is_staff:
+            raise Http404
+        
+        if not self.extra_context: self.extra_context = dict()
+        
+        context['page'] = page
+        context['paginate_by'] = self.paginate_by
+        context['extra_context'] = self.extra_context
+        
+        return context
+    
+    def get_queryset(self):
+        profile_model = get_profile_model()
+        queryset = profile_model.objects.get_visible_profiles(self.request.user)
+        return queryset      
+        
 @secure_required
 def signup(request, signup_form=SignupForm,
            template_name='userena/signup_form.html', success_url=None,
@@ -69,6 +116,11 @@ def signup(request, signup_form=SignupForm,
         if form.is_valid():
             user = form.save()
 
+            # Send the signup complete signal
+            userena_signals.signup_complete.send(sender=None,
+                                                 user=user)
+
+
             if success_url: redirect_to = success_url
             else: redirect_to = reverse('userena_signup_complete',
                                         kwargs={'username': user.username})
@@ -80,9 +132,9 @@ def signup(request, signup_form=SignupForm,
 
     if not extra_context: extra_context = dict()
     extra_context['form'] = form
-    return direct_to_template(request,
-                              template_name,
-                              extra_context=extra_context)
+    return ExtraContextTemplateView.as_view(template_name=template_name,
+                                            extra_context=extra_context)(request)
+
 @secure_required
 def activate(request, username, activation_key,
              template_name='userena/activate_fail.html',
@@ -110,9 +162,10 @@ def activate(request, username, activation_key,
         ``userena/activation_fail.html``.
 
     :param success_url:
-        Named URL where the user should be redirected to after a succesfull
-        activation. If not specified, will direct to
-        ``userena_profile_detail`` view.
+        String containing the URL where the user should be redirected to after
+        a succesfull activation. Will replace ``%(username)s`` with string
+        formatting if supplied. If ``success_url`` is left empty, will direct
+        to ``userena_profile_detail`` view.
 
     :param extra_context:
         Dictionary containing variables which could be added to the template
@@ -130,15 +183,14 @@ def activate(request, username, activation_key,
             messages.success(request, _('Your account has been activated and you have been signed in.'),
                              fail_silently=True)
 
-        if success_url: redirect_to = success_url
+        if success_url: redirect_to = success_url % {'username': user.username }
         else: redirect_to = reverse('userena_profile_detail',
                                     kwargs={'username': user.username})
         return redirect(redirect_to)
     else:
         if not extra_context: extra_context = dict()
-        return direct_to_template(request,
-                                  template_name,
-                                  extra_context=extra_context)
+        return ExtraContextTemplateView.as_view(template_name=template_name,
+                                            extra_context=extra_context)(request)
 
 @secure_required
 def email_confirm(request, username, confirmation_key,
@@ -166,8 +218,9 @@ def email_confirm(request, username, confirmation_key,
         needed because the user will be redirected to ``success_url``.
 
     :param success_url:
-        Named URL which is redirected to after a succesfull confirmation.
-        Supplied argument must be able to be rendered by ``reverse`` function.
+        String containing the URL which is redirected to after a succesfull
+        confirmation.  Supplied argument must be able to be rendered by
+        ``reverse`` function.
 
     :param extra_context:
         Dictionary of variables that are passed on to the template supplied by
@@ -182,9 +235,8 @@ def email_confirm(request, username, confirmation_key,
         return redirect(redirect_to)
     else:
         if not extra_context: extra_context = dict()
-        return direct_to_template(request,
-                                  template_name,
-                                  extra_context=extra_context)
+        return ExtraContextTemplateView.as_view(template_name=template_name,
+                                            extra_context=extra_context)(request)
 
 def direct_to_user_template(request, username, template_name,
                             extra_context=None):
@@ -220,10 +272,9 @@ def direct_to_user_template(request, username, template_name,
 
     if not extra_context: extra_context = dict()
     extra_context['viewed_user'] = user
-    return direct_to_template(request,
-                              template_name,
-                              extra_context=extra_context)
-
+    extra_context['profile'] = user.get_profile()
+    return ExtraContextTemplateView.as_view(template_name=template_name,
+                                            extra_context=extra_context)(request)
 @secure_required
 def signin(request, auth_form=AuthenticationForm,
            template_name='userena/signin_form.html',
@@ -298,16 +349,36 @@ def signin(request, auth_form=AuthenticationForm,
                                         kwargs={'username': user.username}))
 
     if not extra_context: extra_context = dict()
-    extra_context['form'] = form
-    return direct_to_template(request,
-                              template_name,
-                              extra_context=extra_context)
+    extra_context.update({
+        'form': form,
+        'next': request.REQUEST.get(redirect_field_name),
+    })
+    return ExtraContextTemplateView.as_view(template_name=template_name,
+                                            extra_context=extra_context)(request)
 
+@secure_required
+def signout(request, next_page=userena_settings.USERENA_REDIRECT_ON_SIGNOUT, 
+            template_name='userena/signout.html', *args, **kwargs):
+    """
+    Signs out the user and adds a success message ``You have been signed
+    out.`` If next_page is defined you will be redirected to the URI. If
+    not the template in template_name is used.
 
+    :param next_page:
+        A string which specifies the URI to redirect to.
+
+    :param template_name:
+        String defining the name of the template to use. Defaults to
+        ``userena/signout.html``.
+
+    """
+    if request.user.is_authenticated() and userena_settings.USERENA_USE_MESSAGES: # pragma: no cover
+        messages.success(request, _('You have been signed out.'), fail_silently=True)
+    return Signout(request, next_page, template_name, *args, **kwargs)
 
 @secure_required
 @permission_required_or_403('change_user', (User, 'username', 'username'))
-def email_change(request, username, form=ChangeEmailForm,
+def email_change(request, username, email_form=ChangeEmailForm,
                  template_name='userena/email_form.html', success_url=None,
                  extra_context=None):
     """
@@ -316,7 +387,7 @@ def email_change(request, username, form=ChangeEmailForm,
     :param username:
         String of the username which specifies the current account.
 
-    :param form:
+    :param email_form:
         Form that will be used to change the email address. Defaults to
         :class:`ChangeEmailForm` supplied by userena.
 
@@ -351,10 +422,10 @@ def email_change(request, username, form=ChangeEmailForm,
     """
     user = get_object_or_404(User, username__iexact=username)
 
-    form = ChangeEmailForm(user)
+    form = email_form(user)
 
     if request.method == 'POST':
-        form = ChangeEmailForm(user,
+        form = email_form(user,
                                request.POST,
                                request.FILES)
 
@@ -368,9 +439,9 @@ def email_change(request, username, form=ChangeEmailForm,
 
     if not extra_context: extra_context = dict()
     extra_context['form'] = form
-    return direct_to_template(request,
-                              template_name,
-                              extra_context=extra_context)
+    extra_context['profile'] = user.get_profile()
+    return ExtraContextTemplateView.as_view(template_name=template_name,
+                                            extra_context=extra_context)(request)
 
 @secure_required
 @permission_required_or_403('change_user', (User, 'username', 'username'))
@@ -433,15 +504,14 @@ def password_change(request, username, template_name='userena/password_form.html
 
     if not extra_context: extra_context = dict()
     extra_context['form'] = form
-    return direct_to_template(request,
-                              template_name,
-                              extra_context=extra_context)
-
+    extra_context['profile'] = user.get_profile()
+    return ExtraContextTemplateView.as_view(template_name=template_name,
+                                            extra_context=extra_context)(request)
 @secure_required
 @permission_required_or_403('change_profile', (get_profile_model(), 'user__username', 'username'))
 def profile_edit(request, username, edit_profile_form=EditProfileForm,
                  template_name='userena/profile_form.html', success_url=None,
-                 extra_context=None):
+                 extra_context=None, **kwargs):
     """
     Edit profile.
 
@@ -511,11 +581,12 @@ def profile_edit(request, username, edit_profile_form=EditProfileForm,
     if not extra_context: extra_context = dict()
     extra_context['form'] = form
     extra_context['profile'] = profile
-    return direct_to_template(request,
-                              template_name,
-                              extra_context=extra_context)
-
-def profile_detail(request, username, template_name='userena/profile_detail.html', extra_context=None):
+    return ExtraContextTemplateView.as_view(template_name=template_name,
+                                            extra_context=extra_context)(request)
+def profile_detail(
+    request, username,
+    template_name=userena_settings.USERENA_PROFILE_DETAIL_TEMPLATE,
+    extra_context=None, **kwargs):
     """
     Detailed view of an user.
 
@@ -543,12 +614,12 @@ def profile_detail(request, username, template_name='userena/profile_detail.html
         return HttpResponseForbidden(_("You don't have permission to view this profile."))
     if not extra_context: extra_context = dict()
     extra_context['profile'] = user.get_profile()
-    return direct_to_template(request,
-                              template_name,
-                              extra_context=extra_context)
+    extra_context['hide_email'] = userena_settings.USERENA_HIDE_EMAIL
+    return ExtraContextTemplateView.as_view(template_name=template_name,
+                                            extra_context=extra_context)(request)
 
 def profile_list(request, page=1, template_name='userena/profile_list.html',
-                 paginate_by=50, extra_context=None, **kwargs):
+                 paginate_by=50, extra_context=None, **kwargs): # pragma: no cover
     """
     Returns a list of all profiles that are public.
 
@@ -588,6 +659,8 @@ def profile_list(request, page=1, template_name='userena/profile_list.html',
         An instance of ``django.core.paginator.Page``.
 
     """
+    warnings.warn("views.profile_list is deprecated. Use ProfileListView instead", DeprecationWarning, stacklevel=2)
+
     try:
         page = int(request.GET.get('page', None))
     except (TypeError, ValueError):
